@@ -9,6 +9,7 @@ from annotell.base_clients.http_client import HttpClient
 import annotell.input_api.model as IAM
 from annotell.input_api.model import IMUData
 from annotell.input_api.model.ego.validated_imu_data import ValidatedIMUData, ValidateIMUDataRequest
+from annotell.input_api.model.input.feature_flags import FeatureFlags
 from annotell.input_api.model.input.initialized_input import InitializedInput
 from annotell.input_api.model.input.input_from_scene_request import InputFromSceneRequest
 
@@ -32,7 +33,8 @@ class CreateableInputAPIResource:
         batch: Optional[str],
         annotation_types: Optional[List[str]] = None,
         imu_data: Optional[List[IMUData]] = None,
-        dryrun: bool = False
+        dryrun: bool = False,
+        feature_flags: Optional[FeatureFlags] = None
     ) -> Optional[IAM.InputJobCreated]:
         """
         Send input to Input API. if dryrun is true, only validation is performed
@@ -45,6 +47,10 @@ class CreateableInputAPIResource:
 
         body = self._append_annotation_types(body, annotation_types)
 
+        feature_flags = feature_flags if feature_flags is not None else FeatureFlags.defaults
+
+        body = self._append_feature_flags(body, feature_flags)
+
         input_job_json = self._validate_and_create_scene(
             resource_path=resource_path, body=body, project=project, batch=batch, dryrun=dryrun
         )
@@ -91,8 +97,19 @@ class CreateableInputAPIResource:
             body['annotationTypes'] = annotation_types
         return body
 
+    def _append_feature_flags(self, body: Dict, feature_flags: Optional[FeatureFlags]) -> Dict:
+        if feature_flags:
+            body['featureFlags'] = feature_flags.to_dict()
+        return body
+
     def _validate_and_create_scene(
-        self, *, resource_path: str, body: dict, project: Optional[str], batch: Optional[str], dryrun: bool = False
+            self,
+            *,
+            resource_path: str,
+            body: dict,
+            project: Optional[str],
+            batch: Optional[str],
+            dryrun: bool = False
     ) -> Optional[Dict]:
 
         log.debug("POST:ing to %s input %s", resource_path, body)
