@@ -2,6 +2,7 @@ import logging
 from typing import List, Optional
 
 import annotell.input_api.model.input as InputModel
+from annotell.input_api.model.input.feature_flags import FeatureFlags
 from annotell.input_api.resources.abstract import CreateableInputAPIResource
 
 log = logging.getLogger(__name__)
@@ -16,7 +17,8 @@ class Cameras(CreateableInputAPIResource):
         project: Optional[str] = None,
         batch: Optional[str] = None,
         annotation_types: Optional[List[str]] = None,
-        dryrun: bool = False
+        dryrun: bool = False,
+        feature_flags: Optional[FeatureFlags] = None
     ) -> Optional[InputModel.CreateInputResponse]:
         """
         Upload files and create an input of type ``cameras``.
@@ -26,13 +28,15 @@ class Cameras(CreateableInputAPIResource):
         :param batch: batch, defaults to latest open batch
         :param annotation_types: annotation types for which to produce annotations for. Defaults to `None` (corresponds to all available annotation types). Passing an empty list will result in the same behaviour as passing `None`.
         :param dryrun: If True the files/metadata will be validated but no input job will be created.
+        :param feature_flags Optional set of feature flags to control the input creation process.
         :returns InputJobCreated: Class containing id of the created input job, or `None` if dryrun.
         """
 
         payload = cameras.to_dict()
 
         response = self._post_input_request(
-            self.path, payload, project=project, batch=batch, annotation_types=annotation_types, dryrun=dryrun
+            self.path, payload, project=project, batch=batch, annotation_types=annotation_types,
+            dryrun=dryrun, feature_flags=feature_flags
         )
 
         if dryrun:
